@@ -1,4 +1,4 @@
-// This file Copyright © 2008-2022 Mnemosyne LLC.
+// This file Copyright © 2008-2023 Mnemosyne LLC.
 // It may be used under GPLv2 (SPDX: GPL-2.0-only), GPLv3 (SPDX: GPL-3.0-only),
 // or any future license endorsed by Mnemosyne LLC.
 // License text can be found in the licenses/ folder.
@@ -832,7 +832,7 @@ void tr_rpc_server::setPassword(std::string_view password) noexcept
 
 void tr_rpc_server::setPasswordEnabled(bool enabled)
 {
-    is_password_enabled_ = enabled;
+    authentication_required_ = enabled;
     tr_logAddDebug(fmt::format("setting password-enabled to '{}'", enabled));
 }
 
@@ -891,8 +891,8 @@ void tr_rpc_server::load(tr_variant* src)
     {
         tr_logAddWarn(fmt::format(
             _("The '{key}' setting is '{value}' but must be an IPv4 or IPv6 address or a Unix socket path. Using default value '0.0.0.0'"),
-            fmt::format("key", tr_quark_get_string_view(TR_KEY_rpc_bind_address)),
-            fmt::format("value", bind_address_str_)));
+            fmt::arg("key", tr_quark_get_string_view(TR_KEY_rpc_bind_address)),
+            fmt::arg("value", bind_address_str_)));
         bind_address_->set_inaddr_any();
     }
 
