@@ -12,8 +12,12 @@
 + (NSString*)stringForFileSize:(uint64_t)size;
 + (NSString*)stringForFilePartialSize:(uint64_t)partialSize fullSize:(uint64_t)fullSize;
 
+// 4 significant digits
 + (NSString*)stringForSpeed:(CGFloat)speed;
+// 4 significant digits
 + (NSString*)stringForSpeedAbbrev:(CGFloat)speed;
+// 3 significant digits
++ (NSString*)stringForSpeedAbbrevCompact:(CGFloat)speed;
 + (NSString*)stringForRatio:(CGFloat)ratio;
 
 + (NSString*)percentString:(CGFloat)progress longDecimals:(BOOL)longDecimals;
