@@ -4,7 +4,13 @@
 
 @import AppKit;
 
+#include <libtransmission/transmission.h>
+
+#include <libtransmission/utils.h>
+
 int main(int argc, char** argv)
 {
+    tr_locale_set_global("");
+
     return NSApplicationMain(argc, (char const**)argv);
 }
