@@ -32,7 +32,7 @@ namespace libtransmission::test
 
 bool waitFor(struct event_base* event_base, std::chrono::milliseconds msec)
 {
-    return waitFor(
+    return waitFor( //
         event_base,
         []() { return false; },
         msec);
@@ -497,7 +497,7 @@ TEST_F(DhtTest, stopsBootstrappingWhenSwarmHealthIsGoodEnough)
     waitFor(event_base_, MockTimerInterval * 10);
 
     // Confirm that the number of nodes pinged is unchanged,
-    // indicating that boostrapping is done
+    // indicating that bootstrapping is done
     EXPECT_EQ(TurnGoodAfterNthPing, std::size(mock_dht.pinged_));
 }
 
@@ -566,7 +566,7 @@ TEST_F(DhtTest, usesBootstrapFile)
     // Confirm that BootstrapNodeName gets pinged first.
     auto const expected = getSockaddr(BootstrapNodeName, BootstrapNodePort);
     auto& pinged = mediator.mock_dht_.pinged_;
-    waitFor(
+    waitFor( //
         event_base_,
         [&pinged]() { return !std::empty(pinged); },
         5s);
